@@ -1,16 +1,7 @@
 package File::DataClass;
 
 use 5.010001;
-use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.56.%d', q$Rev: 1 $ =~ /\d+/gmx );
-
-use Moo;
-
-my $F_DC_Cache = {};
-
-sub F_DC_Cache {
-   return $F_DC_Cache;
-}
+use version; our $VERSION = qv( sprintf '0.57.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 1;
 
@@ -18,20 +9,21 @@ __END__
 
 =pod
 
-=begin markdown
+=begin html
 
-[![Build Status](https://travis-ci.org/pjfl/p5-file-dataclass.svg?branch=master)](https://travis-ci.org/pjfl/p5-file-dataclass)
-[![CPAN version](https://badge.fury.io/pl/File-DataClass.svg)](http://badge.fury.io/pl/File-DataClass)
+<a href="https://travis-ci.org/pjfl/p5-file-dataclass"><img src="https://travis-ci.org/pjfl/p5-file-dataclass.svg?branch=master" alt="Travis CI Badge"></a>
+<a href="http://badge.fury.io/pl/File-DataClass"><img src="https://badge.fury.io/pl/File-DataClass.svg" alt="CPAN Badge"></a>
+<a href="http://cpants.cpanauthors.org/dist/File-DataClass"><img src="http://cpants.cpanauthors.org/dist/File-DataClass.png" alt="Kwalitee Badge"></a>
 
-=end markdown
+=end html
 
 =head1 Name
 
-File::DataClass - Structured data file IO with OO paradigm
+File::DataClass - Structured data file IO with caching and searching
 
 =head1 Version
 
-This document describes version v0.56.$Rev: 1 $ of L<File::DataClass>
+This document describes version v0.57.$Rev: 1 $ of L<File::DataClass>
 
 =head1 Synopsis
 
@@ -66,12 +58,7 @@ Defines no attributes
 
 =head1 Subroutines/Methods
 
-=head2 F_DC_Cache
-
-   $hash_ref_of_CHI_objects = File::DataClass->F_DC_Cache;
-
-A class method which returns a hash ref of L<CHI> objects which are
-used to cache the results of reading files
+None
 
 =head1 Diagnostics
 
